@@ -10,48 +10,51 @@ use warnings;
 use warnings::register;
 
 use vars qw($VERSION $DATE $FILE );
-$VERSION = '0.05';
-$DATE = '2003/07/05';
+$VERSION = '0.06';
+$DATE = '2003/08/01';
 $FILE = __FILE__;
 
 use vars qw(%INVENTORY);
 %INVENTORY = (
-    'lib/Docs/Site_SVD/Test_STDmaker.pm' => [qw(0.05 2003/07/05), 'revised 0.04'],
-    'MANIFEST' => [qw(0.05 2003/07/05), 'generated, replaces 0.04'],
-    'Makefile.PL' => [qw(0.05 2003/07/05), 'generated, replaces 0.04'],
-    'README' => [qw(0.05 2003/07/05), 'generated, replaces 0.04'],
-    'lib/Test/STDmaker.pm' => [qw(1.08 2003/07/05), 'revised 1.07'],
-    'lib/Test/STDType/Demo.pm' => [qw(1.06 2003/07/05), 'unchanged'],
-    'lib/Test/STDType/STD.pm' => [qw(1.07 2003/07/05), 'revised 1.06'],
-    'lib/Test/STDType/Verify.pm' => [qw(1.06 2003/07/04), 'unchanged'],
-    'lib/Test/STD/Check.pm' => [qw(1.06 2003/07/04), 'unchanged'],
+    'lib/Docs/Site_SVD/Test_STDmaker.pm' => [qw(0.06 2003/08/01), 'revised 0.05'],
+    'MANIFEST' => [qw(0.06 2003/08/01), 'generated, replaces 0.05'],
+    'Makefile.PL' => [qw(0.06 2003/08/01), 'generated, replaces 0.05'],
+    'README' => [qw(0.06 2003/08/01), 'generated, replaces 0.05'],
+    'lib/Test/STDmaker.pm' => [qw(1.09 2003/08/01), 'revised 1.08'],
+    'lib/Test/STDType/Demo.pm' => [qw(1.07 2003/08/01), 'revised 1.06'],
+    'lib/Test/STDType/STD.pm' => [qw(1.07 2003/07/05), 'unchanged'],
+    'lib/Test/STDType/Verify.pm' => [qw(1.07 2003/08/01), 'revised 1.06'],
+    'lib/Test/STD/Check.pm' => [qw(1.07 2003/08/01), 'revised 1.06'],
     'lib/Test/STD/FileGen.pm' => [qw(1.06 2003/07/05), 'unchanged'],
     'lib/Test/STD/STD2167.pm' => [qw(1.04 2003/07/05), 'unchanged'],
-    'lib/Test/STD/STDgen.pm' => [qw(1.04 2003/07/05), 'revised 1.03'],
+    'lib/Test/STD/STDgen.pm' => [qw(1.04 2003/07/05), 'unchanged'],
     't/Test/STDmaker/FileGenI.pm' => [qw(1.02 2003/06/14), 'unchanged'],
-    't/Test/STDmaker/STDmaker.d' => [qw(0.01 2003/07/05), 'unchanged'],
-    't/Test/STDmaker/STDmaker.pm' => [qw(0.05 2003/07/05), 'revised 0.04'],
-    't/Test/STDmaker/STDmaker.t' => [qw(0.01 2003/07/05), 'unchanged'],
+    't/Test/STDmaker/STDmaker.d' => [qw(0.07 2003/08/01), 'revised 0.06'],
+    't/Test/STDmaker/STDmaker.pm' => [qw(0.06 2003/08/01), 'revised 0.05'],
+    't/Test/STDmaker/STDmaker.t' => [qw(0.07 2003/08/01), 'revised 0.06'],
+    't/Test/STDmaker/temp0.pl' => [qw(0.06 2003/08/01), 'new'],
     't/Test/STDmaker/tg0.pm' => [qw(0.02 2003/06/14), 'unchanged'],
-    't/Test/STDmaker/tg2.pm' => [qw(0.02 2003/06/21), 'unchanged'],
+    't/Test/STDmaker/tg2n.pm' => [qw(0.02 2003/08/01), 'new'],
+    't/Test/STDmaker/tg2s.pm' => [qw(0.02 2003/08/01), 'new'],
     't/Test/STDmaker/tgA0.pm' => [qw(0.02 2003/06/21), 'unchanged'],
-    't/Test/STDmaker/tgA1.pm' => [qw(0.02 2003/06/21), 'unchanged'],
     't/Test/STDmaker/tgA2.pm' => [qw(0.02 2003/06/21), 'unchanged'],
-    't/Test/STDmaker/tgA2A.txt' => [qw(0.03 2003/06/21), 'unchanged'],
-    't/Test/STDmaker/tgA2B.txt' => [qw(0.04 2003/07/04), 'unchanged'],
-    't/Test/STDmaker/tgA2C.txt' => [qw(0.05 2003/07/04), 'unchanged'],
-    't/Test/STDmaker/tgA2D.txt' => [qw(0.02 2003/06/05), 'unchanged'],
+    't/Test/STDmaker/tgA2An.txt' => [qw(0.06 2003/08/01), 'new'],
+    't/Test/STDmaker/tgA2As.txt' => [qw(0.06 2003/08/01), 'new'],
+    't/Test/STDmaker/tgA2B.txt' => [qw(0.05 2003/08/01), 'revised 0.04'],
+    't/Test/STDmaker/tgA2C.txt' => [qw(0.06 2003/08/01), 'revised 0.05'],
+    't/Test/STDmaker/tgA2D.txt' => [qw(0.03 2003/08/01), 'revised 0.02'],
     't/Test/STDmaker/tgB0n.pm' => [qw(0.01 2003/06/21), 'unchanged'],
     't/Test/STDmaker/tgB0s.pm' => [qw(0.01 2003/06/21), 'unchanged'],
-    't/Test/STDmaker/tgB1.pm' => [qw(0.01 2003/06/07), 'unchanged'],
-    't/Test/STDmaker/tgB2n.pm' => [qw(0.01 2003/06/21), 'unchanged'],
+    't/Test/STDmaker/tgB2n.pm' => [qw(0.02 2003/08/01), 'revised 0.01'],
     't/Test/STDmaker/tgB2n.txt' => [qw(0.02 2003/06/21), 'unchanged'],
     't/Test/STDmaker/tgB2s.pm' => [qw(0.01 2003/06/21), 'unchanged'],
     't/Test/STDmaker/tgB2s.txt' => [qw(0.02 2003/06/21), 'unchanged'],
     't/Test/STDmaker/tgC0.pm' => [qw(0.02 2003/06/21), 'unchanged'],
-    't/Test/STDmaker/tgC1.pm' => [qw(0.01 2003/06/07), 'unchanged'],
     't/Test/STDmaker/tgC2.pm' => [qw(0.02 2003/06/21), 'unchanged'],
-    'bin/tmake.pl' => [qw(1.04 2003/07/05), 'unchanged'],
+    't/Test/STDmaker/lib/Test.pm' => [qw(1.24 2003/08/01), 'new'],
+    'bin/tmake.pl' => [qw(1.05 2003/08/01), 'revised 1.04'],
+    'tlib/Text/Scrub.pm' => [qw(1.09 2003/08/01), 'new'],
+    'tlib/Test/Tech.pm' => [qw(1.12 2003/08/01), 'new'],
 
 );
 
@@ -78,11 +81,11 @@ use vars qw(%INVENTORY);
 
  Test::STDmaker - Test Scripts, Demo Scripts and Software Test Description (STD) Automation
 
- Revision: D
+ Revision: E
 
- Version: 0.05
+ Version: 0.06
 
- Date: 2003/07/05
+ Date: 2003/08/01
 
  Prepared for: General Public 
 
@@ -211,7 +214,7 @@ The dependency of the program modules in the US DOD STD2167A bundle is as follow
 
 =head2 1.3 Document overview.
 
-This document releases Test::STDmaker version 0.05
+This document releases Test::STDmaker version 0.06
 providing description of the inventory, installation
 instructions and other information necessary to
 utilize and track this release.
@@ -227,8 +230,8 @@ system file specification.
 This document releases the file found
 at the following repository(s):
 
-   http://www.softwarediamonds/packages/Test-STDmaker-0.05
-   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/Test-STDmaker-0.05
+   http://www.softwarediamonds/packages/Test-STDmaker-0.06
+   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/Test-STDmaker-0.06
 
 
 Restrictions regarding duplication and license provisions
@@ -305,42 +308,45 @@ consists of the following files:
 
  file                                                         version date       comment
  ------------------------------------------------------------ ------- ---------- ------------------------
- lib/Docs/Site_SVD/Test_STDmaker.pm                           0.05    2003/07/05 revised 0.04
- MANIFEST                                                     0.05    2003/07/05 generated, replaces 0.04
- Makefile.PL                                                  0.05    2003/07/05 generated, replaces 0.04
- README                                                       0.05    2003/07/05 generated, replaces 0.04
- lib/Test/STDmaker.pm                                         1.08    2003/07/05 revised 1.07
- lib/Test/STDType/Demo.pm                                     1.06    2003/07/05 unchanged
- lib/Test/STDType/STD.pm                                      1.07    2003/07/05 revised 1.06
- lib/Test/STDType/Verify.pm                                   1.06    2003/07/04 unchanged
- lib/Test/STD/Check.pm                                        1.06    2003/07/04 unchanged
+ lib/Docs/Site_SVD/Test_STDmaker.pm                           0.06    2003/08/01 revised 0.05
+ MANIFEST                                                     0.06    2003/08/01 generated, replaces 0.05
+ Makefile.PL                                                  0.06    2003/08/01 generated, replaces 0.05
+ README                                                       0.06    2003/08/01 generated, replaces 0.05
+ lib/Test/STDmaker.pm                                         1.09    2003/08/01 revised 1.08
+ lib/Test/STDType/Demo.pm                                     1.07    2003/08/01 revised 1.06
+ lib/Test/STDType/STD.pm                                      1.07    2003/07/05 unchanged
+ lib/Test/STDType/Verify.pm                                   1.07    2003/08/01 revised 1.06
+ lib/Test/STD/Check.pm                                        1.07    2003/08/01 revised 1.06
  lib/Test/STD/FileGen.pm                                      1.06    2003/07/05 unchanged
  lib/Test/STD/STD2167.pm                                      1.04    2003/07/05 unchanged
- lib/Test/STD/STDgen.pm                                       1.04    2003/07/05 revised 1.03
+ lib/Test/STD/STDgen.pm                                       1.04    2003/07/05 unchanged
  t/Test/STDmaker/FileGenI.pm                                  1.02    2003/06/14 unchanged
- t/Test/STDmaker/STDmaker.d                                   0.01    2003/07/05 unchanged
- t/Test/STDmaker/STDmaker.pm                                  0.05    2003/07/05 revised 0.04
- t/Test/STDmaker/STDmaker.t                                   0.01    2003/07/05 unchanged
+ t/Test/STDmaker/STDmaker.d                                   0.07    2003/08/01 revised 0.06
+ t/Test/STDmaker/STDmaker.pm                                  0.06    2003/08/01 revised 0.05
+ t/Test/STDmaker/STDmaker.t                                   0.07    2003/08/01 revised 0.06
+ t/Test/STDmaker/temp0.pl                                     0.06    2003/08/01 new
  t/Test/STDmaker/tg0.pm                                       0.02    2003/06/14 unchanged
- t/Test/STDmaker/tg2.pm                                       0.02    2003/06/21 unchanged
+ t/Test/STDmaker/tg2n.pm                                      0.02    2003/08/01 new
+ t/Test/STDmaker/tg2s.pm                                      0.02    2003/08/01 new
  t/Test/STDmaker/tgA0.pm                                      0.02    2003/06/21 unchanged
- t/Test/STDmaker/tgA1.pm                                      0.02    2003/06/21 unchanged
  t/Test/STDmaker/tgA2.pm                                      0.02    2003/06/21 unchanged
- t/Test/STDmaker/tgA2A.txt                                    0.03    2003/06/21 unchanged
- t/Test/STDmaker/tgA2B.txt                                    0.04    2003/07/04 unchanged
- t/Test/STDmaker/tgA2C.txt                                    0.05    2003/07/04 unchanged
- t/Test/STDmaker/tgA2D.txt                                    0.02    2003/06/05 unchanged
+ t/Test/STDmaker/tgA2An.txt                                   0.06    2003/08/01 new
+ t/Test/STDmaker/tgA2As.txt                                   0.06    2003/08/01 new
+ t/Test/STDmaker/tgA2B.txt                                    0.05    2003/08/01 revised 0.04
+ t/Test/STDmaker/tgA2C.txt                                    0.06    2003/08/01 revised 0.05
+ t/Test/STDmaker/tgA2D.txt                                    0.03    2003/08/01 revised 0.02
  t/Test/STDmaker/tgB0n.pm                                     0.01    2003/06/21 unchanged
  t/Test/STDmaker/tgB0s.pm                                     0.01    2003/06/21 unchanged
- t/Test/STDmaker/tgB1.pm                                      0.01    2003/06/07 unchanged
- t/Test/STDmaker/tgB2n.pm                                     0.01    2003/06/21 unchanged
+ t/Test/STDmaker/tgB2n.pm                                     0.02    2003/08/01 revised 0.01
  t/Test/STDmaker/tgB2n.txt                                    0.02    2003/06/21 unchanged
  t/Test/STDmaker/tgB2s.pm                                     0.01    2003/06/21 unchanged
  t/Test/STDmaker/tgB2s.txt                                    0.02    2003/06/21 unchanged
  t/Test/STDmaker/tgC0.pm                                      0.02    2003/06/21 unchanged
- t/Test/STDmaker/tgC1.pm                                      0.01    2003/06/07 unchanged
  t/Test/STDmaker/tgC2.pm                                      0.02    2003/06/21 unchanged
- bin/tmake.pl                                                 1.04    2003/07/05 unchanged
+ t/Test/STDmaker/lib/Test.pm                                  1.24    2003/08/01 new
+ bin/tmake.pl                                                 1.05    2003/08/01 revised 1.04
+ tlib/Text/Scrub.pm                                           1.09    2003/08/01 new
+ tlib/Test/Tech.pm                                            1.12    2003/08/01 new
 
 
 =head2 3.3 Changes
@@ -349,12 +355,12 @@ Changes are as follows:
 
 =over 4
 
-=item STD::STDgen 0.01
+=item STD-STDgen-0.01
 
 This is the original release. 
 There are no previous releases to change.
 
-=item STD::STDgen 0.02
+=item STD-STDgen-0.02
 
 =over 4
 
@@ -383,8 +389,7 @@ looping work
 
 =back
 
-
-=item Test::STDmaker 0.01
+=item Test-STDmaker-0.01
 
 =over 4
 
@@ -400,7 +405,7 @@ directives to use existing top levels whenever possible.
 
 =back
 
-=item Test::STDmaker 0.02
+=item Test-STDmaker-0.02
 
 Replaced using Test::TestUtil with File::FileUtil, Test::STD::Scrub, Test::STD::STDutil
 
@@ -413,7 +418,7 @@ surprises because of Test versions.
 Changed the generated test script to use subroutine interface of "Test::Tech"
 The object interface was removed.
 
-=item Test::STDmaker 0.03
+=item Test-STDmaker-0.03
 
 Make the same additions to @INC for "Test::STDtype::Demo" and "Test::STD::Check" as for
 "Test::STDtype::Verify".
@@ -421,32 +426,36 @@ Make the same additions to @INC for "Test::STDtype::Demo" and "Test::STD::Check"
 Changed from using "File::FileUtil" (disappeared) to the File::* modules broken out from
 "File::FileUtil"
 
-=item Test::STDmaker 0.04
+=item Test-STDmaker-0.04
 
 Changed from using "Test::STD::STDutil" (disappeared) to the File::* modules broken out from
 "Test::STD::STDutil"
 
 Added the -options_pm option and the ability to make multiple tests from a file list.
 
-=item Test::STDmaker 0.05
+=item Test-STDmaker-0.05
 
 Chnage name of Test::Table to Test::Column. Test::Table taken.
 
+=item Test-STDmaker-0.06
+
+Added DM Diagnostic Message tag
+
+Change the test so that test support program modules resides in distribution
+directory tlib directory instead of the lib directory. 
+Because they are no longer in the lib directory, 
+test support files will not be installed as a pre-condition for the 
+test of this module.
+The test of this module will precede immediately.
+The test support files in the tlib directory will vanish after
+the installtion.
+
 =back
 
 =head2 3.4 Adaptation data.
 
 This installation requires that the installation site
 has the Perl programming language installed.
-Installation sites running Microsoft Operating systems require
-the installation of Unix utilities. 
-An excellent, highly recommended Unix utilities for Microsoft
-operating systems is unxutils by Karl M. Syring.
-A copy is available at the following web sites:
-
- http://unxutils.sourceforge.net
- http://packages.SoftwareDiamnds.com
-
 There are no other additional requirements or tailoring needed of 
 configurations files, adaptation data or other software needed for this
 installation particular to any installation site.
@@ -474,26 +483,24 @@ Follow the instructions for the the chosen installation software.
 
 The distribution file is at the following respositories:
 
-   http://www.softwarediamonds/packages/Test-STDmaker-0.05
-   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/Test-STDmaker-0.05
+   http://www.softwarediamonds/packages/Test-STDmaker-0.06
+   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/Test-STDmaker-0.06
 
 
 =item Prerequistes.
 
- 'DataPort::DataFile' => '0.02',
- 'DataPort::FileType::FormDB' => '0.02',
- 'DataPort::Maker' => '0',
- 'Test::Tech' => '1.08',
- 'Text::Scrub' => '0',
- 'Text::Replace' => '0',
- 'Text::Column' => '0',
- 'File::AnySpec' => '0',
- 'File::TestPath' => '0',
- 'File::SubPM' => '0',
- 'File::PM2File' => '0',
- 'File::SmartNL' => '0',
- 'File::Package' => '0',
- 'File::Data' => '0',
+ 'File::AnySpec' => '1.1',
+ 'File::Data' => '1.1',
+ 'File::Package' => '1.1',
+ 'File::PM2File' => '1.1',
+ 'File::SmartNL' => '1.1',
+ 'File::SubPM' => '1.1',
+ 'File::TestPath' => '1.',
+ 'Text::Replace' => '1.08',
+ 'Text::Column' => '1.08',
+ 'DataPort::FileType::FormDB' => '0.03',
+ 'DataPort::Maker' => '1.04',
+ 'DataPort::DataFile' => '0.04',
 
 
 =item Security, privacy, or safety precautions.
@@ -733,10 +740,10 @@ __DATA__
 DISTNAME: Test-STDmaker^
 REPOSITORY_DIR: packages^
 
-VERSION : 0.05^
+VERSION : 0.06^
 FREEZE: 1^
-PREVIOUS_RELEASE: 0.04^
-REVISION: D^
+PREVIOUS_RELEASE: 0.05^
+REVISION: E^
 
 PREVIOUS_DISTNAME:  ^
 AUTHOR  : SoftwareDiamonds.com E<lt>support@SoftwareDiamonds.comE<gt>^
@@ -777,23 +784,23 @@ t/Test/STDmaker/*
 t/Test/STDmaker/lib/*
 t/Test/STDmaker/lib/Data/*
 bin/tmake.pl
+lib/Text/Scrub.pm => tlib/Text/Scrub.pm
+lib/Test/Tech.pm => tlib/Test/Tech.pm
 ^
 
 PREREQ_PM:
-'DataPort::DataFile' => '0.02',
-'DataPort::FileType::FormDB' => '0.02',
-'DataPort::Maker' => '0',
-'Test::Tech' => '1.08',
-'Text::Scrub' => '0',
-'Text::Replace' => '0',
-'Text::Column' => '0',
-'File::AnySpec' => '0',
-'File::TestPath' => '0',
-'File::SubPM' => '0',
-'File::PM2File' => '0',
-'File::SmartNL' => '0',
-'File::Package' => '0',
-'File::Data' => '0',
+'File::AnySpec' => '1.1',
+'File::Data' => '1.1',
+'File::Package' => '1.1',
+'File::PM2File' => '1.1',
+'File::SmartNL' => '1.1',
+'File::SubPM' => '1.1',
+'File::TestPath' => '1.',
+'Text::Replace' => '1.08',
+'Text::Column' => '1.08',
+'DataPort::FileType::FormDB' => '0.03',
+'DataPort::Maker' => '1.04',
+'DataPort::DataFile' => '0.04',
 ^
 
 TESTS: t/Test/STDmaker/STDmaker.t^
@@ -911,12 +918,12 @@ Changes are as follows:
 
 \=over 4
 
-\=item STD::STDgen 0.01
+\=item STD-STDgen-0.01
 
 This is the original release. 
 There are no previous releases to change.
 
-\=item STD::STDgen 0.02
+\=item STD-STDgen-0.02
 
 \=over 4
 
@@ -945,8 +952,7 @@ looping work
 
 \=back
 
-
-\=item Test::STDmaker 0.01
+\=item Test-STDmaker-0.01
 
 \=over 4
 
@@ -962,7 +968,7 @@ directives to use existing top levels whenever possible.
 
 \=back
 
-\=item Test::STDmaker 0.02
+\=item Test-STDmaker-0.02
 
 Replaced using Test::TestUtil with File::FileUtil, Test::STD::Scrub, Test::STD::STDutil
 
@@ -975,7 +981,7 @@ surprises because of Test versions.
 Changed the generated test script to use subroutine interface of "Test::Tech"
 The object interface was removed.
 
-\=item Test::STDmaker 0.03
+\=item Test-STDmaker-0.03
 
 Make the same additions to @INC for "Test::STDtype::Demo" and "Test::STD::Check" as for
 "Test::STDtype::Verify".
@@ -983,17 +989,30 @@ Make the same additions to @INC for "Test::STDtype::Demo" and "Test::STD::Check"
 Changed from using "File::FileUtil" (disappeared) to the File::* modules broken out from
 "File::FileUtil"
 
-\=item Test::STDmaker 0.04
+\=item Test-STDmaker-0.04
 
 Changed from using "Test::STD::STDutil" (disappeared) to the File::* modules broken out from
 "Test::STD::STDutil"
 
 Added the -options_pm option and the ability to make multiple tests from a file list.
 
-\=item Test::STDmaker 0.05
+\=item Test-STDmaker-0.05
 
 Chnage name of Test::Table to Test::Column. Test::Table taken.
 
+\=item Test-STDmaker-0.06
+
+Added DM Diagnostic Message tag
+
+Change the test so that test support program modules resides in distribution
+directory tlib directory instead of the lib directory. 
+Because they are no longer in the lib directory, 
+test support files will not be installed as a pre-condition for the 
+test of this module.
+The test of this module will precede immediately.
+The test support files in the tlib directory will vanish after
+the installtion.
+
 \=back
 
 ^
