@@ -17,8 +17,8 @@ use File::SubPM;
 use File::PM2File;
 
 use vars qw($VERSION $DATE);
-$VERSION = '1.08';
-$DATE = '2003/07/05';
+$VERSION = '1.09';
+$DATE = '2003/08/01';
 
 use DataPort::Maker;
 use vars qw(@ISA);
@@ -1278,6 +1278,8 @@ follow on the next lines. For example,
  =>     my $tgB0_pm = ($internal_number eq 'string') ? 'tgB0s.pm' : 'tgB0n.pm';
  =>     my $tgB2_pm = ($internal_number eq 'string') ? 'tgB2s.pm' : 'tgB2n.pm';
  =>     my $tgB2_txt = ($internal_number eq 'string') ? 'tgB2s.txt' : 'tgB2n.txt';
+ =>     my $tgA2A_txt = ($internal_number eq 'string') ? 'tgA2As.txt' : 'tgA2An.txt';
+ =>     my $tg2_pm = ($internal_number eq 'string') ? 'tg2s.pm' : 'tg2n.pm';
 
  =>     my $test_results;
  =>     my $loaded = 0;
@@ -2038,7 +2040,7 @@ follow on the next lines. For example,
  =head2 ok: 2
 
    A: [($x+$y,$y-$x)]^
-   E: ['\'5\',\'2\'']^
+   E: ['5,2']^
   ok: 2^
 
  #######
@@ -2131,7 +2133,7 @@ follow on the next lines. For example,
  ok: 1^
 
   A: [($x+$y,$y-$x)]^
-  E: ['\'5\',\'2\'']^
+  E: ['5,2']^
  ok: 2^
 
  See_Also: L<Test::STDmaker::tg1>^
@@ -2161,10 +2163,10 @@ follow on the next lines. For example,
  '1..2
  ok 1
  not ok 2
- # Test 2 got: ''5'
- '1'
+ # Test 2 got: '5
+ 1
  ' (xxxx.t at line 000)
- #   Expected: ''5','2''
+ #   Expected: '5,2'
  '
 
  => $snl->fin( 'tg0.pm'  )
@@ -2330,16 +2332,16 @@ follow on the next lines. For example,
   => my $x = 2
   => my $y = 3
   => $x + $y
-  '5'
+  5
 
   => $y-$x
-  '1'
+  1
 
   => $x+4
-  '6'
+  6
 
   => $x*$y*2
-  '12'
+  12
 
   => $x
   2
@@ -2348,34 +2350,34 @@ follow on the next lines. For example,
   =>     my $i;
   =>     for( $i=0; $i < 3; $i++) {
   => $i+200
-  '200'
+  200
 
   => $i + ($x * 100)
-  '200'
+  200
 
   =>     };
   => $i+200
-  '201'
+  201
 
   => $i + ($x * 100)
-  '201'
+  201
 
   =>     };
   => $i+200
-  '202'
+  202
 
   => $i + ($x * 100)
-  '202'
+  202
 
   =>     };
   => $x + $y
-  '5'
+  5
 
   => $x + $y + $x
-  '7'
+  7
 
   => $x + $y + $x + $y
-  '10'
+  10
 
  =head1 SEE ALSO
 
@@ -2410,13 +2412,13 @@ follow on the next lines. For example,
  # Test that fails
  not ok 3
  # Test 3 got: '6' (xxxx.t at line 000)
- #   Expected: '7'
+ #   Expected: '7' (Test that fails)
  # Skipped tests
  ok 4 # skip
  # Todo Test that Fails
  not ok 5
  # Test 5 got: '12' (xxxx.t at line 000 *TODO*)
- #   Expected: '6'
+ #   Expected: '6' (Todo Test that Fails)
  # verify only
  ok 6
  # Test loop
@@ -2431,7 +2433,7 @@ follow on the next lines. For example,
  # Failed test that skips the rest
  not ok 13
  # Test 13 got: '5' (xxxx.t at line 000)
- #    Expected: '6'
+ #    Expected: '6' (Failed test that skips the rest)
  # A test to skip
  # Test invalid because of previous failure.
  ok 14 # skip
@@ -2442,8 +2444,8 @@ follow on the next lines. For example,
  # Test invalid because of previous failure.
  ok 16 # skip
  FAILED tests 3, 13
- 	Failed 2/16 tests, 87.50% okay (-4 skipped tests: 10 okay, 62.50%)
- Failed Test                      Status Wstat Total Fail  Failed  List of Failed
+ 	Failed 2/16 tests, 87.50% okay (less 4 skipped tests: 10 okay, 62.50%)
+ Failed Test                       Stat Wstat Total Fail  Failed  List of Failed
 
    (1 subtest UNEXPECTEDLY SUCCEEDED), 4 subtests skipped.
  Failed 1/1 test scripts, 0.00% okay. 2/16 subtests failed, 87.50% okay.
