@@ -10,8 +10,8 @@ use warnings;
 use warnings::register;
 
 use vars qw($VERSION $DATE $FILE );
-$VERSION = '0.05';
-$DATE = '2003/07/05';
+$VERSION = '0.06';
+$DATE = '2003/08/01';
 $FILE = __FILE__;
 
 ########
@@ -40,7 +40,7 @@ $FILE = __FILE__;
 
  Version: 
 
- Date: 2003/07/05
+ Date: 2003/08/01
 
  Prepared for: General Public 
 
@@ -105,6 +105,8 @@ L<STD FormDB Test Description Fields|Test::STDmaker/STD FormDB Test Description
      my $tgB0_pm = ($internal_number eq 'string') ? 'tgB0s.pm' : 'tgB0n.pm';
      my $tgB2_pm = ($internal_number eq 'string') ? 'tgB2s.pm' : 'tgB2n.pm';
      my $tgB2_txt = ($internal_number eq 'string') ? 'tgB2s.txt' : 'tgB2n.txt';
+     my $tgA2A_txt = ($internal_number eq 'string') ? 'tgA2As.txt' : 'tgA2An.txt';
+     my $tg2_pm = ($internal_number eq 'string') ? 'tg2s.pm' : 'tg2n.pm';
      my $test_results;
      my $loaded = 0;
      my @outputs;
@@ -137,6 +139,7 @@ L<STD FormDB Test Description Fields|Test::STDmaker/STD FormDB Test Description
      #  unlink <tg1*.*>;  causes subsequent bsd_blog calls to crash
      #
  ^
+ DM: For a valid test, the UUT should not be loaded^
   N: UUT not loaded^
   A: $loaded = $fp->is_package_loaded('Test::STDmaker')^
   E:  ''^
@@ -252,7 +255,7 @@ L<STD FormDB Test Description Fields|Test::STDmaker/STD FormDB Test Description
  ^
   A: $test_results^
   N: Demonstration script^
-  E: $snl->fin('tgA2A.txt')^
+  E: $snl->fin($tgA2A_txt)^
  ok: 7^
 
 =head2 ok: 8
@@ -302,7 +305,7 @@ L<STD FormDB Test Description Fields|Test::STDmaker/STD FormDB Test Description
  ^
   A: $s->scrub_date_version($snl->fin('tg1.pm'))^
   N: Generate and replace a demonstration^
-  E: $s->scrub_date_version($snl->fin('tg2.pm'))^
+  E: $s->scrub_date_version($snl->fin($tg2_pm))^
  ok: 9^
 
 =head2 ok: 10
@@ -538,7 +541,7 @@ ANY WAY OUT OF THE POSSIBILITY OF SUCH DAMAGE.
 
 =head1 SEE ALSO
 
-\over 4
+=over 4
 
 =item L<STD Automated Generation|Test::STDmaker>
 
@@ -554,7 +557,7 @@ ANY WAY OUT OF THE POSSIBILITY OF SUCH DAMAGE.
 
 =item L<File::PM2File|File::PM2File>
 
-=item L<File::SubPM|File::PSubPM>
+=item L<File::SubPM|File::SubPM>
 
 =item L<Text::Replace|Text::Replace>
 
@@ -634,6 +637,8 @@ Verify: STDmaker.t^
     my $tgB0_pm = ($internal_number eq 'string') ? 'tgB0s.pm' : 'tgB0n.pm';
     my $tgB2_pm = ($internal_number eq 'string') ? 'tgB2s.pm' : 'tgB2n.pm';
     my $tgB2_txt = ($internal_number eq 'string') ? 'tgB2s.txt' : 'tgB2n.txt';
+    my $tgA2A_txt = ($internal_number eq 'string') ? 'tgA2As.txt' : 'tgA2An.txt';
+    my $tg2_pm = ($internal_number eq 'string') ? 'tg2s.pm' : 'tg2n.pm';
 
     my $test_results;
     my $loaded = 0;
@@ -671,6 +676,7 @@ VO: ^
     #
 ^
 
+DM: For a valid test, the UUT should not be loaded^
  N: UUT not loaded^
  A: $loaded = $fp->is_package_loaded('Test::STDmaker')^
  E:  ''^
@@ -783,7 +789,7 @@ VO: ^
 
  A: $test_results^
  N: Demonstration script^
- E: $snl->fin('tgA2A.txt')^
+ E: $snl->fin($tgA2A_txt)^
 ok: 7^
 
 VO: ^
@@ -832,7 +838,7 @@ DO: ^
 
  A: $s->scrub_date_version($snl->fin('tg1.pm'))^
  N: Generate and replace a demonstration^
- E: $s->scrub_date_version($snl->fin('tg2.pm'))^
+ E: $s->scrub_date_version($snl->fin($tg2_pm))^
 ok: 9^
 
 
@@ -946,39 +952,39 @@ ok: 12^
 
 
 See_Also:
-\over 4
+\=over 4
 
-=item L<STD Automated Generation|Test::STDmaker>
+\=item L<STD Automated Generation|Test::STDmaker>
 
-=item L<File::Package|File::Package>
+\=item L<File::Package|File::Package>
 
-=item L<File::SmartNL|File::SmartNL>
+\=item L<File::SmartNL|File::SmartNL>
 
-=item L<File::TestPath|File::TestPath>
+\=item L<File::TestPath|File::TestPath>
 
-=item L<File::AnySpec|File::AnySpec>
+\=item L<File::AnySpec|File::AnySpec>
 
-=item L<File::Data|File::Data>
+\=item L<File::Data|File::Data>
 
-=item L<File::PM2File|File::PM2File>
+\=item L<File::PM2File|File::PM2File>
 
-=item L<File::SubPM|File::PSubPM>
+\=item L<File::SubPM|File::SubPM>
 
-=item L<Text::Replace|Text::Replace>
+\=item L<Text::Replace|Text::Replace>
 
-=item L<Text::Column|Text::Column>
+\=item L<Text::Column|Text::Column>
 
-=item L<Text::Scrub|Text::::Scrub>
+\=item L<Text::Scrub|Text::::Scrub>
 
-=item L<DataPort::FileType::FormDB|DataPort::FileType::FormDB>
+\=item L<DataPort::FileType::FormDB|DataPort::FileType::FormDB>
 
-=item L<Software Development Standard|Docs::US_DOD::STD2167A>
+\=item L<Software Development Standard|Docs::US_DOD::STD2167A>
 
-=item L<Specification Practices|Docs::US_DOD::STD490A>
+\=item L<Specification Practices|Docs::US_DOD::STD490A>
 
-=item L<STD DID|US_DOD::STD>
+\=item L<STD DID|US_DOD::STD>
 
-=item L<Test Harness|Test::Harness>
+\=item L<Test Harness|Test::Harness>
 
 =back
 ^
@@ -992,15 +998,15 @@ and use in source and binary forms, with or
 without modification, provided that the 
 following conditions are met: 
 
-=over 4
+\=over 4
 
-=item 1
+\=item 1
 
 Redistributions of source code, modified or unmodified
 must retain the above copyright notice, this list of
 conditions and the following disclaimer. 
 
-=item 2
+\=item 2
 
 Redistributions in binary form must 
 reproduce the above copyright notice,
@@ -1009,7 +1015,7 @@ disclaimer in the documentation and/or
 other materials provided with the
 distribution.
 
-=back
+\=back
 
 SOFTWARE DIAMONDS, http://www.SoftwareDiamonds.com,
 PROVIDES THIS SOFTWARE 
